@@ -336,7 +336,8 @@ where
 
                     let mut tokens = vec![];
 
-                    while !is_one_of!(self, EOF, ";") {
+                    // TODO fix me
+                    while !is_one_of!(self, EOF, ";", "}") {
                         tokens.extend(self.input.bump()?);
                     }
 
